FbNewsConfig class
Constructors
Properties
- backgroundColor → Color?
-
Set the Color of the background
final
- borderColor → Color?
-
Set the Color of the border
final
-
fields
→ List<
FbNewsFieldName> -
Select which fields to display
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkColor → Color?
-
Set the Color of a link
final
- noDataOrError → Widget?
-
The noDataOrError widget is displayed if the response contains no data or an error
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBorder → bool
-
Toogle the display of the border
final
- subtitle → String
-
Subtitle in the every feeditem
final
- textColor → Color?
-
Set the Color of the text
final
- waiting → Widget?
-
The waiting widget is displayed when the data is loaded
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited